---
title: <span class="badge object-type-scalar"></span> GigaWatt
---
# <span class="badge object-type-scalar"></span> GigaWatt

Energy: Gigawatt (GW)

## Definition

```python
# Energy: Gigawatt (GW)
GigaWatt: typing.Literal["gwatt"] = "gwatt"
```
